==> xlnl-3.4.8.tar.gz: xlnl-3.4.8/src/sound-kind.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: sound-kind.h,v 1.5 2009/05/31 07:23:45 bowkenken Exp $
***************************************************************/

#ifndef	SOUND_KIND_KIND_H
#define	SOUND_KIND_KIND_H

/* SE (Sound Effect) μ */

typedef enum {
	SOUND_KIND_NULL,

	SOUND_KIND_TRAP_SAFE,
	SOUND_KIND_TRAP_DISARM,
	SOUND_KIND_TRAP_CAUGHT,

	SOUND_KIND_SPELL_SOR,
	SOUND_KIND_SPELL_ENC,
	SOUND_KIND_SPELL_NIN,
	SOUND_KIND_SPELL_BAR,
	SOUND_KIND_SPELL_MAG,
	SOUND_KIND_SPELL_SUM,
	SOUND_KIND_SPELL_SHA,
	SOUND_KIND_SPELL_PRI,

	SOUND_KIND_BLAST_MEMBER,
	SOUND_KIND_BLAST_MONSTER,
	SOUND_KIND_BLAST_DESTRUCTION,

	SOUND_KIND_MENU_CANCEL,
	SOUND_KIND_MENU_SELECT,

	SOUND_KIND_FIGHT_DIE_MEMBER,
	SOUND_KIND_FIGHT_DIE_MONSTER_BOSS_LAST,
	SOUND_KIND_FIGHT_DIE_MONSTER_BOSS,
	SOUND_KIND_FIGHT_DIE_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER_BOSS_LAST,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_HIT_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_HIT_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER,
	SOUND_KIND_FIGHT_FIND_MEMBER,
	SOUND_KIND_FIGHT_FIND_MONSTER_BOSS,
	SOUND_KIND_FIGHT_FIND_MONSTER,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_ATTACK,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_WEAKEN,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_SLAP,
	SOUND_KIND_FIGHT_ATTACK_THROW_MEMBER,
	SOUND_KIND_FIGHT_ATTACK_THROW_MONSTER,

	SOUND_KIND_REQUEST_FINISH,

	SOUND_KIND_SHOP_SALE,
	SOUND_KIND_SHOP_BUY_DRINK,
	SOUND_KIND_SHOP_BUY,

	SOUND_KIND_EVENT_GATE,
	SOUND_KIND_EVENT_DRIVE,
	SOUND_KIND_EVENT_EARTHQUAKE,

	SOUND_KIND_LEVEL_DOWN,
	SOUND_KIND_LEVEL_UP,

	SOUND_KIND_DOOR_CLOSE,
	SOUND_KIND_DOOR_OPEN,

	SOUND_KIND_STAIRS_DOWN,
	SOUND_KIND_STAIRS_UP,

	SOUND_KIND_ITEM_USE,
	SOUND_KIND_ITEM_OPEN,
	SOUND_KIND_ITEM_SMOKE,

	SOUND_KIND_MAX_N,
} sound_kind_t;

#endif	/* SOUND_KIND_KIND_H */

==> xlnl-3.4.20.tar.gz: xlnl-3.4.20/src/sound-kind.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: sound-kind.h,v 1.9 2014/01/07 23:40:42 bowkenken Exp $
***************************************************************/

#ifndef	SOUND_KIND_KIND_H
#define	SOUND_KIND_KIND_H

/* SE (Sound Effect) μ */

typedef enum {
	SOUND_KIND_NULL,

	SOUND_KIND_TRAP_SAFE,
	SOUND_KIND_TRAP_DISARM,
	SOUND_KIND_TRAP_CAUGHT,

	SOUND_KIND_SPELL_SOR,
	SOUND_KIND_SPELL_ENC,
	SOUND_KIND_SPELL_NIN,
	SOUND_KIND_SPELL_BAR,
	SOUND_KIND_SPELL_MAG,
	SOUND_KIND_SPELL_SUM,
	SOUND_KIND_SPELL_SHA,
	SOUND_KIND_SPELL_PRI,

	SOUND_KIND_BLAST_MEMBER,
	SOUND_KIND_BLAST_MONSTER,
	SOUND_KIND_BLAST_DESTRUCTION,

	SOUND_KIND_MENU_CANCEL,
	SOUND_KIND_MENU_SELECT,

	SOUND_KIND_FIGHT_DIE_MEMBER,
	SOUND_KIND_FIGHT_DIE_MONSTER_BOSS_LAST,
	SOUND_KIND_FIGHT_DIE_MONSTER_BOSS,
	SOUND_KIND_FIGHT_DIE_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER_BOSS_LAST,
	SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_HIT_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_HIT_MONSTER,
	SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER,
	SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER,
	SOUND_KIND_FIGHT_FIND_MEMBER,
	SOUND_KIND_FIGHT_FIND_MONSTER_BOSS,
	SOUND_KIND_FIGHT_FIND_MONSTER,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_ATTACK,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_WEAKEN,
	SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_SLAP,
	SOUND_KIND_FIGHT_ATTACK_THROW_MEMBER,
	SOUND_KIND_FIGHT_ATTACK_THROW_MONSTER,

	SOUND_KIND_REQUEST_FINISH,

	SOUND_KIND_SHOP_SALE,
	SOUND_KIND_SHOP_BUY_DRINK,
	SOUND_KIND_SHOP_BUY,

	SOUND_KIND_EVENT_GATE,
	SOUND_KIND_EVENT_DRIVE,
	SOUND_KIND_EVENT_EARTHQUAKE,

	SOUND_KIND_LEVEL_DOWN,
	SOUND_KIND_LEVEL_UP,

	SOUND_KIND_DOOR_CLOSE,
	SOUND_KIND_DOOR_OPEN,

	SOUND_KIND_STAIRS_DOWN,
	SOUND_KIND_STAIRS_UP,

	SOUND_KIND_ITEM_USE,
	SOUND_KIND_ITEM_OPEN,
	SOUND_KIND_ITEM_SMOKE,

	SOUND_KIND_ACTION_APPEAR,
	SOUND_KIND_ACTION_TELEPORT_RECALL,
	SOUND_KIND_ACTION_TELEPORT_PARTY,
	SOUND_KIND_ACTION_TELEPORT_SHORT,
	SOUND_KIND_ACTION_TELEPORT_LONG,

	SOUND_KIND_MAX_N,
} sound_kind_t;

#endif	/* SOUND_KIND_KIND_H */
